=== modified file 'drizzled/create_field.cc'
--- drizzled/create_field.cc	2010-05-29 01:13:40 +0000
+++ drizzled/create_field.cc	2010-07-16 05:40:08 +0000
@@ -69,7 +69,7 @@
 
   /* Fix if the original table had 4 byte pointer blobs */
   if (flags & BLOB_FLAG)
-    pack_length= (pack_length - old_field->table->getShare()->blob_ptr_size + portable_sizeof_char_ptr);
+    pack_length= (pack_length - old_field->getTable()->getShare()->blob_ptr_size + portable_sizeof_char_ptr);
 
   switch (sql_type) 
   {
@@ -97,13 +97,13 @@
   if (!(flags & (NO_DEFAULT_VALUE_FLAG )) &&
       old_field->ptr && orig_field &&
       (sql_type != DRIZZLE_TYPE_TIMESTAMP ||                /* set def only if */
-       old_field->table->timestamp_field != old_field ||  /* timestamp field */
+       old_field->getTable()->timestamp_field != old_field ||  /* timestamp field */
        unireg_check == Field::TIMESTAMP_UN_FIELD))        /* has default val */
   {
     ptrdiff_t diff;
 
     /* Get the value from default_values */
-    diff= (ptrdiff_t) (orig_field->table->getDefaultValues() - orig_field->table->record[0]);
+    diff= (ptrdiff_t) (orig_field->getTable()->getDefaultValues() - orig_field->getTable()->record[0]);
     orig_field->move_field_offset(diff);	// Points now at default_values
     if (! orig_field->is_real_null())
     {

=== modified file 'drizzled/field.h'
--- drizzled/field.h	2010-07-09 08:40:41 +0000
+++ drizzled/field.h	2010-07-16 05:40:08 +0000
@@ -96,13 +96,26 @@
    * @note You can use table->in_use as replacement for current_session member
    * only inside of val_*() and store() members (e.g. you can't use it in cons)
    */
+private:
   Table *table;
+public:
   Table *getTable()
   {
     assert(table);
     return table;
   }
 
+  Table *getTable() const
+  {
+    assert(table);
+    return table;
+  }
+
+  void setTable(Table *table_arg)
+  {
+    table= table_arg;
+  }
+
   Table *orig_table; /**< Pointer to the original Table. @TODO What is "the original table"? */
   const char **table_name; /**< Pointer to the name of the table. @TODO This is redundant with Table::table_name. */
   const char *field_name; /**< Name of the field */

=== modified file 'drizzled/field/blob.cc'
--- drizzled/field/blob.cc	2010-05-20 06:34:25 +0000
+++ drizzled/field/blob.cc	2010-07-16 05:40:08 +0000
@@ -107,7 +107,7 @@
 void Field_blob::store_length(unsigned char *i_ptr, uint32_t i_packlength,
                   uint32_t i_number)
 {
-  store_length(i_ptr, i_packlength, i_number, table->getShare()->db_low_byte_first);
+  store_length(i_ptr, i_packlength, i_number, getTable()->getShare()->db_low_byte_first);
 }
 
 
@@ -160,13 +160,13 @@
 uint32_t Field_blob::get_length(uint32_t row_offset)
 {
   return get_length(ptr+row_offset, this->packlength,
-                    table->getShare()->db_low_byte_first);
+                    getTable()->getShare()->db_low_byte_first);
 }
 
 
 uint32_t Field_blob::get_length(const unsigned char *ptr_arg)
 {
-  return get_length(ptr_arg, this->packlength, table->getShare()->db_low_byte_first);
+  return get_length(ptr_arg, this->packlength, getTable()->getShare()->db_low_byte_first);
 }
 
 
@@ -531,7 +531,7 @@
 
 uint32_t Field_blob::pack_length() const
 {
-  return (uint32_t) (packlength+table->getShare()->blob_ptr_size);
+  return (uint32_t) (packlength + getTable()->getShare()->blob_ptr_size);
 }
 
 void Field_blob::sql_type(String &res) const
@@ -594,7 +594,7 @@
   uint32_t const master_packlength=
     param_data > 0 ? param_data & 0xFF : packlength;
   uint32_t const length= get_length(from, master_packlength, low_byte_first);
-  table->setWriteSet(field_index);
+  getTable()->setWriteSet(field_index);
   store(reinterpret_cast<const char*>(from) + master_packlength,
         length, field_charset);
   return(from + master_packlength + length);

=== modified file 'drizzled/field/decimal.cc'
--- drizzled/field/decimal.cc	2010-02-26 08:21:58 +0000
+++ drizzled/field/decimal.cc	2010-07-16 05:40:08 +0000
@@ -150,17 +150,17 @@
                            ~(E_DEC_OVERFLOW | E_DEC_BAD_NUM),
                            from, length, charset_arg,
                            &decimal_value)) &&
-      table->in_use->abort_on_warning)
+      getTable()->in_use->abort_on_warning)
   {
     /* Because "from" is not NUL-terminated and we use %s in the ER() */
     String from_as_str;
     from_as_str.copy(from, length, &my_charset_bin);
 
-    push_warning_printf(table->in_use, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
+    push_warning_printf(getTable()->in_use, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
                         ER_TRUNCATED_WRONG_VALUE_FOR_FIELD,
                         ER(ER_TRUNCATED_WRONG_VALUE_FOR_FIELD),
                         "decimal", from_as_str.c_ptr(), field_name,
-                        (uint32_t) table->in_use->row_count);
+                        (uint32_t) getTable()->in_use->row_count);
 
     return(err);
   }
@@ -180,11 +180,11 @@
       String from_as_str;
       from_as_str.copy(from, length, &my_charset_bin);
 
-      push_warning_printf(table->in_use, DRIZZLE_ERROR::WARN_LEVEL_WARN,
+      push_warning_printf(getTable()->in_use, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                           ER_TRUNCATED_WRONG_VALUE_FOR_FIELD,
                           ER(ER_TRUNCATED_WRONG_VALUE_FOR_FIELD),
                           "decimal", from_as_str.c_ptr(), field_name,
-                          (uint32_t) table->in_use->row_count);
+                          (uint32_t) getTable()->in_use->row_count);
       my_decimal_set_zero(&decimal_value);
 
       break;
@@ -216,11 +216,11 @@
     if (check_overflow(err))
       set_value_on_overflow(&decimal_value, decimal_value.sign());
     /* Only issue a warning if store_value doesn't issue an warning */
-    table->in_use->got_warning= 0;
+    getTable()->in_use->got_warning= 0;
   }
   if (store_value(&decimal_value))
     err= 1;
-  else if (err && !table->in_use->got_warning)
+  else if (err && !getTable()->in_use->got_warning)
     err= warn_if_overflow(err);
   return(err);
 }
@@ -239,11 +239,11 @@
     if (check_overflow(err))
       set_value_on_overflow(&decimal_value, decimal_value.sign());
     /* Only issue a warning if store_value doesn't issue an warning */
-    table->in_use->got_warning= 0;
+    getTable()->in_use->got_warning= 0;
   }
   if (store_value(&decimal_value))
     err= 1;
-  else if (err && !table->in_use->got_warning)
+  else if (err && not getTable()->in_use->got_warning)
     err= warn_if_overflow(err);
   return err;
 }

=== modified file 'drizzled/field/double.cc'
--- drizzled/field/double.cc	2010-02-04 08:14:46 +0000
+++ drizzled/field/double.cc	2010-07-16 05:40:08 +0000
@@ -48,7 +48,7 @@
   double nr= my_strntod(cs,(char*) from, len, &end, &error);
 
   ASSERT_COLUMN_MARKED_FOR_WRITE;
-  if (error || (!len || (((uint32_t) (end-from) != len) && table->in_use->count_cuted_fields)))
+  if (error || (!len || (((uint32_t) (end-from) != len) && getTable()->in_use->count_cuted_fields)))
   {
     set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
                 (error ? ER_WARN_DATA_OUT_OF_RANGE : ER_WARN_DATA_TRUNCATED), 1);
@@ -66,7 +66,7 @@
   ASSERT_COLUMN_MARKED_FOR_WRITE;
 
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->getShare()->db_low_byte_first)
   {
     float8store(ptr,nr);
   }

=== modified file 'drizzled/field/int64_t.cc'
--- drizzled/field/int64_t.cc	2010-02-04 08:14:46 +0000
+++ drizzled/field/int64_t.cc	2010-07-16 05:40:08 +0000
@@ -53,13 +53,13 @@
     set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_OUT_OF_RANGE, 1);
     error= 1;
   }
-  else if (table->in_use->count_cuted_fields &&
+  else if (getTable()->in_use->count_cuted_fields &&
            check_int(cs, from, len, end, error))
     error= 1;
   else
     error= 0;
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
   {
     int8store(ptr,tmp);
   }
@@ -96,7 +96,7 @@
     set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_OUT_OF_RANGE, 1);
 
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
   {
     int8store(ptr,res);
   }
@@ -114,7 +114,7 @@
   ASSERT_COLUMN_MARKED_FOR_WRITE;
 
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
   {
     int8store(ptr,nr);
   }
@@ -132,7 +132,7 @@
   ASSERT_COLUMN_MARKED_FOR_READ;
 
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
   {
     j=sint8korr(ptr);
   }
@@ -151,7 +151,7 @@
   ASSERT_COLUMN_MARKED_FOR_READ;
 
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
     j=sint8korr(ptr);
   else
 #endif
@@ -173,7 +173,7 @@
   ASSERT_COLUMN_MARKED_FOR_READ;
 
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
     j=sint8korr(ptr);
   else
 #endif
@@ -189,7 +189,7 @@
 {
   int64_t a,b;
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
   {
     a=sint8korr(a_ptr);
     b=sint8korr(b_ptr);
@@ -206,7 +206,7 @@
 void Field_int64_t::sort_string(unsigned char *to,uint32_t )
 {
 #ifdef WORDS_BIGENDIAN
-  if (!table->s->db_low_byte_first)
+  if (!getTable()->s->db_low_byte_first)
   {
     to[0] = (char) (ptr[0] ^ 128);		/* Revers signbit */
     to[1]   = ptr[1];
@@ -250,7 +250,7 @@
 {
   int64_t val;
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
      val = sint8korr(from);
   else
 #endif
@@ -283,7 +283,7 @@
     int64_tget(val, from);
 
 #ifdef WORDS_BIGENDIAN
-  if (table->s->db_low_byte_first)
+  if (getTable()->s->db_low_byte_first)
     int8store(to, val);
   else
 #endif

=== modified file 'drizzled/field/num.cc'
--- drizzled/field/num.cc	2010-02-04 08:14:46 +0000
+++ drizzled/field/num.cc	2010-07-16 05:40:08 +0000
@@ -74,11 +74,11 @@
     char buff[128];
     String tmp(buff, (uint32_t) sizeof(buff), system_charset_info);
     tmp.copy(str, length, system_charset_info);
-    push_warning_printf(table->in_use, DRIZZLE_ERROR::WARN_LEVEL_WARN,
+    push_warning_printf(getTable()->in_use, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                         ER_TRUNCATED_WRONG_VALUE_FOR_FIELD,
                         ER(ER_TRUNCATED_WRONG_VALUE_FOR_FIELD),
                         "integer", tmp.c_ptr(), field_name,
-                        (uint32_t) table->in_use->row_count);
+                        (uint32_t) getTable()->in_use->row_count);
     return 1;
   }
   /* Test if we have garbage at the end of the given string. */
@@ -132,7 +132,7 @@
     goto out_of_range;
   }
 
-  if (table->in_use->count_cuted_fields &&
+  if (getTable()->in_use->count_cuted_fields &&
       check_int(cs, from, len, end, error))
     return 1;
   return 0;

=== modified file 'drizzled/field/str.cc'
--- drizzled/field/str.cc	2010-06-22 19:48:34 +0000
+++ drizzled/field/str.cc	2010-07-16 05:40:08 +0000
@@ -73,7 +73,7 @@
 int
 Field_str::report_if_important_data(const char *field_ptr, const char *end)
 {
-  if ((field_ptr < end) && table->in_use->count_cuted_fields)
+  if ((field_ptr < end) && getTable()->in_use->count_cuted_fields)
   {
     set_warning(DRIZZLE_ERROR::WARN_LEVEL_ERROR, ER_DATA_TOO_LONG, 1);
 
@@ -137,7 +137,7 @@
   length= internal::my_gcvt(nr, internal::MY_GCVT_ARG_DOUBLE, local_char_length, buff, &error);
   if (error)
   {
-    if (table->in_use->abort_on_warning)
+    if (getTable()->in_use->abort_on_warning)
       set_warning(DRIZZLE_ERROR::WARN_LEVEL_ERROR, ER_DATA_TOO_LONG, 1);
     else
       set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
@@ -194,14 +194,14 @@
     *t++= '.';
   }
   *t= '\0';
-  push_warning_printf(field->table->in_use,
-                      field->table->in_use->abort_on_warning ?
+  push_warning_printf(field->getTable()->in_use,
+                      field->getTable()->in_use->abort_on_warning ?
                       DRIZZLE_ERROR::WARN_LEVEL_ERROR :
                       DRIZZLE_ERROR::WARN_LEVEL_WARN,
                       ER_TRUNCATED_WRONG_VALUE_FOR_FIELD,
                       ER(ER_TRUNCATED_WRONG_VALUE_FOR_FIELD),
                       "string", tmp, field->field_name,
-                      (uint32_t) field->table->in_use->row_count);
+                      (uint32_t) field->getTable()->in_use->row_count);
   return true;
 }
 

=== modified file 'drizzled/field/timestamp.cc'
--- drizzled/field/timestamp.cc	2010-06-02 06:19:30 +0000
+++ drizzled/field/timestamp.cc	2010-07-16 05:40:08 +0000
@@ -142,7 +142,7 @@
       function should be called only for first of them (i.e. the one
       having auto-set property).
     */
-    assert(table->timestamp_field == this);
+    assert(getTable()->timestamp_field == this);
     /* Fall-through */
   case TIMESTAMP_DNUN_FIELD:
     return TIMESTAMP_AUTO_SET_ON_BOTH;
@@ -234,7 +234,7 @@
   ASSERT_COLUMN_MARKED_FOR_READ;
 
 #ifdef WORDS_BIGENDIAN
-  if (table && table->s->db_low_byte_first)
+  if (getTable() && getTable()->s->db_low_byte_first)
     temp= uint4korr(ptr);
   else
 #endif
@@ -259,7 +259,7 @@
   to= (char *) val_buffer->ptr();
 
 #ifdef WORDS_BIGENDIAN
-  if (table && table->s->db_low_byte_first)
+  if (getTable() && getTable()->s->db_low_byte_first)
     temp= uint4korr(ptr);
   else
 #endif
@@ -283,7 +283,7 @@
   uint32_t temp;
 
 #ifdef WORDS_BIGENDIAN
-  if (table && table->s->db_low_byte_first)
+  if (getTable() && getTable()->s->db_low_byte_first)
     temp= uint4korr(ptr);
   else
 #endif
@@ -316,7 +316,7 @@
 {
   int32_t a,b;
 #ifdef WORDS_BIGENDIAN
-  if (table && table->s->db_low_byte_first)
+  if (getTable() && getTable()->s->db_low_byte_first)
   {
     a=sint4korr(a_ptr);
     b=sint4korr(b_ptr);
@@ -334,7 +334,7 @@
 void Field_timestamp::sort_string(unsigned char *to,uint32_t )
 {
 #ifdef WORDS_BIGENDIAN
-  if (!table || !table->s->db_low_byte_first)
+  if (!getTable() || !getTable()->s->db_low_byte_first)
   {
     to[0] = ptr[0];
     to[1] = ptr[1];
@@ -358,7 +358,7 @@
 
 void Field_timestamp::set_time()
 {
-  Session *session= table ? table->in_use : current_session;
+  Session *session= getTable() ? getTable()->in_use : current_session;
   long tmp= (long) session->query_start();
   set_notnull();
   store_timestamp(tmp);
@@ -366,7 +366,7 @@
 
 void Field_timestamp::set_default()
 {
-  if (table->timestamp_field == this &&
+  if (getTable()->timestamp_field == this &&
       unireg_check != TIMESTAMP_UN_FIELD)
     set_time();
   else
@@ -378,7 +378,7 @@
   if ((*null_value= is_null()))
     return 0;
 #ifdef WORDS_BIGENDIAN
-  if (table && table->s->db_low_byte_first)
+  if (getTable() && getTable()->s->db_low_byte_first)
     return sint4korr(ptr);
 #endif
   long tmp;
@@ -389,7 +389,7 @@
 void Field_timestamp::store_timestamp(time_t timestamp)
 {
 #ifdef WORDS_BIGENDIAN
-  if (table && table->s->db_low_byte_first)
+  if (getTable() && getTable()->s->db_low_byte_first)
   {
     int4store(ptr,timestamp);
   }

=== modified file 'drizzled/field_conv.cc'
--- drizzled/field_conv.cc	2010-05-20 06:34:25 +0000
+++ drizzled/field_conv.cc	2010-07-16 05:40:08 +0000
@@ -143,12 +143,12 @@
     return 0;
   }
   field->reset();
-  if (field->table->in_use->count_cuted_fields == CHECK_FIELD_WARN)
+  if (field->getTable()->in_use->count_cuted_fields == CHECK_FIELD_WARN)
   {
     field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_TRUNCATED, 1);
     return 0;
   }
-  if (!field->table->in_use->no_errors)
+  if (!field->getTable()->in_use->no_errors)
     my_error(ER_BAD_NULL_ERROR, MYF(0), field->field_name);
   return -1;
 }
@@ -194,17 +194,17 @@
     return 0;					// Ok to set time to NULL
   }
   field->reset();
-  if (field == field->table->next_number_field)
+  if (field == field->getTable()->next_number_field)
   {
-    field->table->auto_increment_field_not_null= false;
+    field->getTable()->auto_increment_field_not_null= false;
     return 0;				  // field is set in fill_record()
   }
-  if (field->table->in_use->count_cuted_fields == CHECK_FIELD_WARN)
+  if (field->getTable()->in_use->count_cuted_fields == CHECK_FIELD_WARN)
   {
     field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_BAD_NULL_ERROR, 1);
     return 0;
   }
-  if (!field->table->in_use->no_errors)
+  if (!field->getTable()->in_use->no_errors)
     my_error(ER_BAD_NULL_ERROR, MYF(0), field->field_name);
   return -1;
 }
@@ -284,7 +284,7 @@
   if (*copy->from_null_ptr & copy->from_bit)
   {
     /* Same as in set_field_to_null_with_conversions() */
-    copy->to_field->table->auto_increment_field_not_null= false;
+    copy->to_field->getTable()->auto_increment_field_not_null= false;
     copy->to_field->reset();
   }
   else
@@ -445,7 +445,7 @@
   if (length > copy->to_length- 1)
   {
     length= copy->to_length - 1;
-    if (copy->from_field->table->in_use->count_cuted_fields)
+    if (copy->from_field->getTable()->in_use->count_cuted_fields)
       copy->to_field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
                                   ER_WARN_DATA_TRUNCATED, 1);
   }
@@ -481,7 +481,7 @@
   if (length > copy->to_length- HA_KEY_BLOB_LENGTH)
   {
     length=copy->to_length-HA_KEY_BLOB_LENGTH;
-    if (copy->from_field->table->in_use->count_cuted_fields)
+    if (copy->from_field->getTable()->in_use->count_cuted_fields)
       copy->to_field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
                                   ER_WARN_DATA_TRUNCATED, 1);
   }
@@ -536,9 +536,9 @@
     to_ptr[0]= 1;                             // Null as default value
     to_null_ptr= (unsigned char*) to_ptr++;
     to_bit= 1;
-    if (from->table->maybe_null)
+    if (from->getTable()->maybe_null)
     {
-      null_row= &from->table->null_row;
+      null_row= &from->getTable()->null_row;
       do_copy= do_outer_field_to_null_str;
     }
     else
@@ -597,7 +597,7 @@
         do_copy= do_copy_null;
       else
       {
-        null_row= &from->table->null_row;
+        null_row= &from->getTable()->null_row;
         do_copy= do_outer_field_null;
       }
     }
@@ -605,7 +605,7 @@
     {
       if (to_field->type() == DRIZZLE_TYPE_TIMESTAMP)
         do_copy= do_copy_timestamp;               // Automatic timestamp
-      else if (to_field == to_field->table->next_number_field)
+      else if (to_field == to_field->getTable()->next_number_field)
         do_copy= do_copy_next_number;
       else
         do_copy= do_copy_not_null;
@@ -632,8 +632,8 @@
 CopyField::Copy_func *
 CopyField::get_copy_func(Field *to,Field *from)
 {
-  bool compatible_db_low_byte_first= (to->table->getShare()->db_low_byte_first ==
-                                     from->table->getShare()->db_low_byte_first);
+  bool compatible_db_low_byte_first= (to->getTable()->getShare()->db_low_byte_first ==
+                                     from->getTable()->getShare()->db_low_byte_first);
   if (to->flags & BLOB_FLAG)
   {
     if (!(from->flags & BLOB_FLAG) || from->charset() != to->charset())
@@ -641,8 +641,8 @@
     if (from_length != to_length || !compatible_db_low_byte_first)
     {
       // Correct pointer to point at char pointer
-      to_ptr+= to_length - to->table->getShare()->blob_ptr_size;
-      from_ptr+= from_length- from->table->getShare()->blob_ptr_size;
+      to_ptr+= to_length - to->getTable()->getShare()->blob_ptr_size;
+      from_ptr+= from_length- from->getTable()->getShare()->blob_ptr_size;
       return do_copy_blob;
     }
   }
@@ -660,7 +660,7 @@
       */
       if (to->real_type() != from->real_type() ||
           !compatible_db_low_byte_first ||
-          (((to->table->in_use->variables.sql_mode & (MODE_NO_ZERO_DATE | MODE_INVALID_DATES)) && to->type() == DRIZZLE_TYPE_DATE) || to->type() == DRIZZLE_TYPE_DATETIME))
+          (((to->getTable()->in_use->variables.sql_mode & (MODE_NO_ZERO_DATE | MODE_INVALID_DATES)) && to->type() == DRIZZLE_TYPE_DATE) || to->type() == DRIZZLE_TYPE_DATETIME))
       {
         if (from->real_type() == DRIZZLE_TYPE_ENUM)
         {
@@ -759,7 +759,7 @@
 int field_conv(Field *to,Field *from)
 {
   if (to->real_type() == from->real_type() &&
-      !(to->type() == DRIZZLE_TYPE_BLOB && to->table->copy_blobs))
+      !(to->type() == DRIZZLE_TYPE_BLOB && to->getTable()->copy_blobs))
   {
     /* Please god, will someone rewrite this to be readable :( */
     if (to->pack_length() == from->pack_length() &&
@@ -767,8 +767,8 @@
         to->real_type() != DRIZZLE_TYPE_ENUM &&
         (to->real_type() != DRIZZLE_TYPE_DECIMAL || (to->field_length == from->field_length && (((Field_num*)to)->dec == ((Field_num*)from)->dec))) &&
         from->charset() == to->charset() &&
-	to->table->getShare()->db_low_byte_first == from->table->getShare()->db_low_byte_first &&
-        (!(to->table->in_use->variables.sql_mode & (MODE_NO_ZERO_DATE | MODE_INVALID_DATES)) || (to->type() != DRIZZLE_TYPE_DATE && to->type() != DRIZZLE_TYPE_DATETIME)) &&
+	to->getTable()->getShare()->db_low_byte_first == from->getTable()->getShare()->db_low_byte_first &&
+        (!(to->getTable()->in_use->variables.sql_mode & (MODE_NO_ZERO_DATE | MODE_INVALID_DATES)) || (to->type() != DRIZZLE_TYPE_DATE && to->type() != DRIZZLE_TYPE_DATETIME)) &&
         (from->real_type() != DRIZZLE_TYPE_VARCHAR || ((Field_varstring*)from)->length_bytes == ((Field_varstring*)to)->length_bytes))
     {						// Identical fields
       /* This may happen if one does 'UPDATE ... SET x=x' */
@@ -785,7 +785,7 @@
       Copy value if copy_blobs is set, or source is not a string and
       we have a pointer to its internal string conversion buffer.
     */
-    if (to->table->copy_blobs ||
+    if (to->getTable()->copy_blobs ||
         (!blob->value.is_alloced() &&
          from->real_type() != DRIZZLE_TYPE_VARCHAR))
       blob->value.copy();

=== modified file 'drizzled/field_iterator.cc'
--- drizzled/field_iterator.cc	2010-06-05 00:14:39 +0000
+++ drizzled/field_iterator.cc	2010-07-16 05:40:08 +0000
@@ -67,7 +67,7 @@
   cur_column_ref= column_ref_it++;
   assert(!cur_column_ref || ! cur_column_ref->table_field ||
               cur_column_ref->table_ref->table ==
-              cur_column_ref->table_field->table);
+              cur_column_ref->table_field->getTable());
 }
 
 
@@ -215,7 +215,7 @@
     assert(nj_col);
   }
   assert(!nj_col->table_field ||
-              nj_col->table_ref->table == nj_col->table_field->table);
+              nj_col->table_ref->table == nj_col->table_field->getTable());
 
   /*
     If the natural join column was just created add it to the list of
@@ -280,7 +280,7 @@
   nj_col= natural_join_it.column_ref();
   assert(nj_col &&
               (!nj_col->table_field ||
-               nj_col->table_ref->table == nj_col->table_field->table));
+               nj_col->table_ref->table == nj_col->table_field->getTable()));
   return nj_col;
 }
 

=== modified file 'drizzled/filesort.cc'
--- drizzled/filesort.cc	2010-06-04 23:50:43 +0000
+++ drizzled/filesort.cc	2010-07-16 05:40:08 +0000
@@ -961,7 +961,7 @@
     Field *field;
     if ((field= sort_field->field))
     {
-      if (field->table == table)
+      if (field->getTable() == table)
         table->setReadSet(field->field_index);
     }
     else

=== modified file 'drizzled/function/set_user_var.cc'
--- drizzled/function/set_user_var.cc	2010-02-04 08:14:46 +0000
+++ drizzled/function/set_user_var.cc	2010-07-16 05:40:08 +0000
@@ -90,8 +90,8 @@
   if (result_field)
   {
     Table *table= (Table *) arg;
-    if (result_field->table == table || !table)
-      result_field->table->setReadSet(result_field->field_index);
+    if (result_field->getTable() == table || !table)
+      result_field->getTable()->setReadSet(result_field->field_index);
   }
   return 0;
 }

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2010-06-03 22:51:07 +0000
+++ drizzled/item.cc	2010-07-16 05:40:08 +0000
@@ -830,7 +830,7 @@
                   0);
     }
     else
-      prev_subselect_item->used_tables_cache|= found_field->table->map;
+      prev_subselect_item->used_tables_cache|= found_field->getTable()->map;
     prev_subselect_item->const_item_cache= 0;
     mark_as_dependent(session, last_select, current_sel, resolved_item,
                       dependent);

=== modified file 'drizzled/item/cmpfunc.cc'
--- drizzled/item/cmpfunc.cc	2010-06-04 04:13:08 +0000
+++ drizzled/item/cmpfunc.cc	2010-07-16 05:40:08 +0000
@@ -5101,7 +5101,7 @@
   while ((item_field= it++))
   {
     /* Skip fields of non-const tables. They haven't been read yet */
-    if (item_field->field->table->const_table)
+    if (item_field->field->getTable()->const_table)
     {
       if ((null_value= item_field->null_value) || eval_item->cmp(item_field))
         return 0;

=== modified file 'drizzled/item/default_value.cc'
--- drizzled/item/default_value.cc	2010-05-28 01:36:09 +0000
+++ drizzled/item/default_value.cc	2010-07-16 05:40:08 +0000
@@ -69,7 +69,7 @@
     goto error;
   memcpy(def_field, field_arg->field, field_arg->field->size_of());
   def_field->move_field_offset((ptrdiff_t)
-                               (def_field->table->getDefaultValues() - def_field->table->record[0]));
+                               (def_field->getTable()->getDefaultValues() - def_field->getTable()->record[0]));
   set_field(def_field);
   return false;
 
@@ -106,7 +106,7 @@
       }
 
       {
-        push_warning_printf(field_arg->table->in_use,
+        push_warning_printf(field_arg->getTable()->in_use,
                             DRIZZLE_ERROR::WARN_LEVEL_WARN,
                             ER_NO_DEFAULT_FOR_FIELD,
                             ER(ER_NO_DEFAULT_FOR_FIELD),

=== modified file 'drizzled/item/field.cc'
--- drizzled/item/field.cc	2010-06-03 22:51:07 +0000
+++ drizzled/item/field.cc	2010-07-16 05:40:08 +0000
@@ -108,8 +108,8 @@
 bool Item_field::register_field_in_read_map(unsigned char *arg)
 {
   Table *table= (Table *) arg;
-  if (field->table == table || !table)
-    field->table->setReadSet(field->field_index);
+  if (field->getTable() == table || !table)
+    field->getTable()->setReadSet(field->field_index);
 
   return 0;
 }
@@ -140,7 +140,7 @@
                        Name_resolution_context *context_arg,
                        Field *f) :
   Item_ident(context_arg,
-             f->table->getShare()->getSchemaName(),
+             f->getTable()->getShare()->getSchemaName(),
              *f->table_name,
              f->field_name),
    item_equal(0),
@@ -194,8 +194,8 @@
   max_length= field_par->max_display_length();
   table_name= *field_par->table_name;
   field_name= field_par->field_name;
-  db_name= field_par->table->getShare()->getSchemaName();
-  alias_name_used= field_par->table->alias_name_used;
+  db_name= field_par->getTable()->getShare()->getSchemaName();
+  alias_name_used= field_par->getTable()->alias_name_used;
   unsigned_flag=test(field_par->flags & UNSIGNED_FLAG);
   collation.set(field_par->charset(), field_par->derivation());
   fixed= 1;
@@ -372,9 +372,9 @@
 
 table_map Item_field::used_tables() const
 {
-  if (field->table->const_table)
+  if (field->getTable()->const_table)
     return 0;					// const item
-  return (depended_from ? OUTER_REF_TABLE_BIT : field->table->map);
+  return (depended_from ? OUTER_REF_TABLE_BIT : field->getTable()->map);
 }
 
 enum Item_result Item_field::result_type () const
@@ -530,7 +530,7 @@
       {
         if (*from_field != view_ref_found)
         {
-          prev_subselect_item->used_tables_cache|= (*from_field)->table->map;
+          prev_subselect_item->used_tables_cache|= (*from_field)->getTable()->map;
           prev_subselect_item->const_item_cache= 0;
           set_field(*from_field);
           if (!last_checked_context->select_lex->having_fix_field &&
@@ -888,7 +888,7 @@
   }
   else if (session->mark_used_columns != MARK_COLUMNS_NONE)
   {
-    Table *table= field->table;
+    Table *table= field->getTable();
     MyBitmap *current_bitmap, *other_bitmap;
     if (session->mark_used_columns == MARK_COLUMNS_READ)
     {
@@ -1200,7 +1200,7 @@
     need to set no_errors to prevent warnings about type conversion
     popping up.
   */
-  Session *session= field->table->in_use;
+  Session *session= field->getTable()->in_use;
   int no_errors;
 
   no_errors= session->no_errors;
@@ -1237,7 +1237,7 @@
   Select_Lex *select= (Select_Lex*)select_arg;
   assert(fixed);
 
-  if (field->table != select->context.table_list->table)
+  if (field->getTable() != select->context.table_list->table)
   {
     List<Item> *all_fields= &select->join->all_fields;
     Item **ref_pointer_array= select->ref_pointer_array;
@@ -1256,7 +1256,7 @@
 
 void Item_field::print(String *str, enum_query_type query_type)
 {
-  if (field && field->table->const_table)
+  if (field && field->getTable()->const_table)
   {
     char buff[MAX_FIELD_WIDTH];
     String tmp(buff,sizeof(buff),str->charset());

=== modified file 'drizzled/item/ident.cc'
--- drizzled/item/ident.cc	2010-04-23 01:02:40 +0000
+++ drizzled/item/ident.cc	2010-07-16 05:40:08 +0000
@@ -191,7 +191,7 @@
   tmp_field->charsetnr= field->charset()->number;
   tmp_field->length=field->field_length;
   tmp_field->type=field->type();
-  tmp_field->flags= field->table->maybe_null ?
+  tmp_field->flags= field->getTable()->maybe_null ?
     (field->flags & ~NOT_NULL_FLAG) : field->flags;
   tmp_field->decimals= field->decimals();
 }

=== modified file 'drizzled/item/insert_value.cc'
--- drizzled/item/insert_value.cc	2010-02-04 08:14:46 +0000
+++ drizzled/item/insert_value.cc	2010-07-16 05:40:08 +0000
@@ -69,15 +69,15 @@
 
   Item_field *field_arg= (Item_field *)arg;
 
-  if (field_arg->field->table->insert_values)
+  if (field_arg->field->getTable()->insert_values)
   {
     Field *def_field= (Field*) memory::sql_alloc(field_arg->field->size_of());
     if (!def_field)
       return true;
     memcpy(def_field, field_arg->field, field_arg->field->size_of());
     def_field->move_field_offset((ptrdiff_t)
-                                 (def_field->table->insert_values -
-                                  def_field->table->record[0]));
+                                 (def_field->getTable()->insert_values -
+                                  def_field->getTable()->record[0]));
     set_field(def_field);
   }
   else
@@ -87,7 +87,7 @@
     tmp_field= new Field_null(0, 0, field_arg->field->field_name, &my_charset_bin);
     if (tmp_field)
     {
-      tmp_field->init(field_arg->field->table);
+      tmp_field->init(field_arg->field->getTable());
       set_field(tmp_field);
     }
   }

=== modified file 'drizzled/item/ref.cc'
--- drizzled/item/ref.cc	2010-02-04 08:14:46 +0000
+++ drizzled/item/ref.cc	2010-07-16 05:40:08 +0000
@@ -244,7 +244,7 @@
               } while (outer_context && outer_context->select_lex &&
                        cached_table->select_lex != outer_context->select_lex);
             }
-            prev_subselect_item->used_tables_cache|= from_field->table->map;
+            prev_subselect_item->used_tables_cache|= from_field->getTable()->map;
             prev_subselect_item->const_item_cache= 0;
             break;
           }

=== modified file 'drizzled/item/sum.cc'
--- drizzled/item/sum.cc	2010-06-05 00:14:39 +0000
+++ drizzled/item/sum.cc	2010-07-16 05:40:08 +0000
@@ -2817,7 +2817,7 @@
     */
     Field *field= item->get_tmp_table_field();
     int res;
-    uint32_t offset= field->offset(field->table->record[0])-table->getShare()->null_bytes;
+    uint32_t offset= field->offset(field->getTable()->record[0])-table->getShare()->null_bytes;
     if((res= field->cmp((unsigned char*)key1 + offset, (unsigned char*)key2 + offset)))
       return res;
   }
@@ -2854,7 +2854,7 @@
     if (field && !item->const_item())
     {
       int res;
-      uint32_t offset= (field->offset(field->table->record[0]) -
+      uint32_t offset= (field->offset(field->getTable()->record[0]) -
                     table->getShare()->null_bytes);
       if ((res= field->cmp((unsigned char*)key1 + offset, (unsigned char*)key2 + offset)))
         return (*order_item)->asc ? res : -res;
@@ -2904,7 +2904,7 @@
         because it contains both order and arg list fields.
       */
       Field *field= (*arg)->get_tmp_table_field();
-      uint32_t offset= (field->offset(field->table->record[0]) -
+      uint32_t offset= (field->offset(field->getTable()->record[0]) -
                     table->getShare()->null_bytes);
       assert(offset < table->getShare()->getRecordLength());
       res= field->val_str(&tmp, key + offset);

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2010-07-04 20:05:46 +0000
+++ drizzled/join.cc	2010-07-16 05:40:08 +0000
@@ -5779,9 +5779,9 @@
     while (iter != sargables.end())
     {
       Field *field= (*iter).getField();
-      JoinTable *join_tab= field->table->reginfo.join_tab;
+      JoinTable *join_tab= field->getTable()->reginfo.join_tab;
       key_map possible_keys= field->key_start;
-      possible_keys&= field->table->keys_in_use_for_query;
+      possible_keys&= field->getTable()->keys_in_use_for_query;
       bool is_const= true;
       for (uint32_t j= 0; j < (*iter).getNumValues(); j++)
         is_const&= (*iter).isConstItem(j);

=== modified file 'drizzled/key.cc'
--- drizzled/key.cc	2010-06-15 13:37:26 +0000
+++ drizzled/key.cc	2010-07-16 05:40:08 +0000
@@ -208,14 +208,14 @@
       field->setReadSet();
       from_key+= HA_KEY_BLOB_LENGTH;
       key_length-= HA_KEY_BLOB_LENGTH;
-      field->set_ptr_offset(to_record - field->table->record[0],
+      field->set_ptr_offset(to_record - field->getTable()->record[0],
                             (ulong) blob_length, from_key);
       length= key_part->length;
     }
     else if (key_part->key_part_flag & HA_VAR_LENGTH_PART)
     {
       Field *field= key_part->field;
-      ptrdiff_t ptrdiff= to_record - field->table->record[0];
+      ptrdiff_t ptrdiff= to_record - field->getTable()->record[0];
 
       field->setReadSet();
       field->setWriteSet();

=== modified file 'drizzled/natural_join_column.cc'
--- drizzled/natural_join_column.cc	2010-05-20 06:34:25 +0000
+++ drizzled/natural_join_column.cc	2010-07-16 05:40:08 +0000
@@ -28,7 +28,7 @@
 Natural_join_column::Natural_join_column(Field *field_param,
                                          TableList *tab)
 {
-  assert(tab->table == field_param->table);
+  assert(tab->table == field_param->getTable());
   table_field= field_param;
   table_ref= tab;
   is_common= false;

=== modified file 'drizzled/optimizer/key_field.cc'
--- drizzled/optimizer/key_field.cc	2010-06-25 19:38:04 +0000
+++ drizzled/optimizer/key_field.cc	2010-07-16 05:40:08 +0000
@@ -36,7 +36,7 @@
                              optimizer::KeyField *key_field)
 {
   Field *field= key_field->getField();
-  Table *form= field->table;
+  Table *form= field->getTable();
 
   if (key_field->isEqualityCondition() &&
       ! (key_field->getOptimizeFlags() & KEY_OPTIMIZE_EXISTS))
@@ -51,7 +51,7 @@
       {
         if (field->eq(form->key_info[key].key_part[part].field))
         {
-          optimizer::KeyUse keyuse(field->table,
+          optimizer::KeyUse keyuse(field->getTable(),
                                    key_field->getValue(),
                                    key_field->getValue()->used_tables(),
                                    key,
@@ -244,7 +244,7 @@
   {
     // Don't remove column IS NULL on a LEFT JOIN table
     if (! eq_func || (*value)->type() != Item::NULL_ITEM ||
-        ! field->table->maybe_null || field->null_ptr)
+        ! field->getTable()->maybe_null || field->null_ptr)
       return;					// Not a key. Skip it
     exists_optimize= KEY_OPTIMIZE_EXISTS;
     assert(num_values == 1);
@@ -256,23 +256,23 @@
     for (uint32_t i= 0; i < num_values; i++)
     {
       used_tables|= (value[i])->used_tables();
-      if (! ((value[i])->used_tables() & (field->table->map | RAND_TABLE_BIT)))
+      if (! ((value[i])->used_tables() & (field->getTable()->map | RAND_TABLE_BIT)))
         optimizable= 1;
     }
     if (! optimizable)
       return;
-    if (! (usable_tables & field->table->map))
+    if (! (usable_tables & field->getTable()->map))
     {
       if (! eq_func || (*value)->type() != Item::NULL_ITEM ||
-          ! field->table->maybe_null || field->null_ptr)
+          ! field->getTable()->maybe_null || field->null_ptr)
         return;					// Can't use left join optimize
       exists_optimize= KEY_OPTIMIZE_EXISTS;
     }
     else
     {
-      JoinTable *stat= field->table->reginfo.join_tab;
+      JoinTable *stat= field->getTable()->reginfo.join_tab;
       key_map possible_keys= field->key_start;
-      possible_keys&= field->table->keys_in_use_for_query;
+      possible_keys&= field->getTable()->keys_in_use_for_query;
       stat[0].keys|= possible_keys;             // Add possible keys
 
       /*

=== modified file 'drizzled/optimizer/range.cc'
--- drizzled/optimizer/range.cc	2010-06-15 13:37:26 +0000
+++ drizzled/optimizer/range.cc	2010-07-16 05:40:08 +0000
@@ -2567,7 +2567,7 @@
   field->setWriteSet();
 
   Item_result cmp_type= field->cmp_type();
-  if (!((ref_tables | field->table->map) & param_comp))
+  if (!((ref_tables | field->getTable()->map) & param_comp))
     ftree= get_func_mm_tree(param, cond_func, field, value, cmp_type, inv);
   Item_equal *item_equal= field_item->item_equal;
   if (item_equal)
@@ -2581,7 +2581,7 @@
 
       if (field->eq(f))
         continue;
-      if (!((ref_tables | f->table->map) & param_comp))
+      if (!((ref_tables | f->getTable()->map) & param_comp))
       {
         tree= get_func_mm_tree(param, cond_func, f, value, cmp_type, inv);
         ftree= !ftree ? tree : tree_and(param, ftree, tree);
@@ -2732,7 +2732,7 @@
       field->setWriteSet();
 
       Item_result cmp_type= field->cmp_type();
-      if (!((ref_tables | field->table->map) & param_comp))
+      if (!((ref_tables | field->getTable()->map) & param_comp))
       {
         tree= get_mm_parts(param, cond, field, Item_func::EQ_FUNC,
 		           value,cmp_type);
@@ -2771,7 +2771,7 @@
 	           Item_func::Functype type,
 	           Item *value, Item_result)
 {
-  if (field->table != param->table)
+  if (field->getTable() != param->table)
     return 0;
 
   KEY_PART *key_part = param->key_parts;
@@ -2841,7 +2841,7 @@
   param->session->mem_root= param->old_root;
   if (!value)					// IS NULL or IS NOT NULL
   {
-    if (field->table->maybe_null)		// Can't use a key on this
+    if (field->getTable()->maybe_null)		// Can't use a key on this
       goto end;
     if (!maybe_null)				// Not null field
     {

=== modified file 'drizzled/optimizer/sum.cc'
--- drizzled/optimizer/sum.cc	2010-06-25 19:38:04 +0000
+++ drizzled/optimizer/sum.cc	2010-07-16 05:40:08 +0000
@@ -239,7 +239,7 @@
 
               ref.key_buff= key_buff;
               Item_field *item_field= (Item_field*) (expr->real_item());
-              Table *table= item_field->field->table;
+              Table *table= item_field->field->getTable();
 
               /*
                  Look for a partial key that can be used for optimization.
@@ -407,7 +407,7 @@
 
               ref.key_buff= key_buff;
               Item_field *item_field= (Item_field*) (expr->real_item());
-              Table *table= item_field->field->table;
+              Table *table= item_field->field->getTable();
 
               /*
                  Look for a partial key that can be used for optimization.
@@ -662,7 +662,7 @@
 
   field->setWriteSet();
 
-  if (! (cond->used_tables() & field->table->map))
+  if (! (cond->used_tables() & field->getTable()->map))
   {
     /* Condition doesn't restrict the used table */
     return 1;
@@ -907,7 +907,7 @@
     return 0; // Not key field
   }
 
-  Table *table= field->table;
+  Table *table= field->getTable();
   uint32_t idx= 0;
 
   KeyInfo *keyinfo,*keyinfo_end= NULL;
@@ -1028,7 +1028,7 @@
                            uint32_t range_fl,
                            uint32_t prefix_len)
 {
-  if (key_cmp_if_same(field->table, ref->key_buff, ref->key, prefix_len))
+  if (key_cmp_if_same(field->getTable(), ref->key_buff, ref->key, prefix_len))
   {
     return 1;
   }
@@ -1069,7 +1069,7 @@
     return 0;
   }
 
-  if (cond->used_tables() != field->table->map)
+  if (cond->used_tables() != field->getTable()->map)
   {
     return 0;
   }

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2010-06-29 22:50:01 +0000
+++ drizzled/sql_base.cc	2010-07-16 05:40:08 +0000
@@ -2500,7 +2500,7 @@
     return NULL;
   {
     /* This is a base table. */
-    assert(nj_col->table_ref->table == nj_col->table_field->table);
+    assert(nj_col->table_ref->table == nj_col->table_field->getTable());
     found_field= nj_col->table_field;
     update_field_dependencies(session, found_field, nj_col->table_ref->table);
   }
@@ -2740,7 +2740,7 @@
         field_to_set= fld;
       if (field_to_set)
       {
-        Table *table= field_to_set->table;
+        Table *table= field_to_set->getTable();
         if (session->mark_used_columns == MARK_COLUMNS_READ)
           table->setReadSet(field_to_set->field_index);
         else
@@ -4171,7 +4171,7 @@
       if ((field= field_iterator.field()))
       {
         /* Mark fields as used to allow storage engine to optimze access */
-        field->table->setReadSet(field->field_index);
+        field->getTable()->setReadSet(field->field_index);
         if (table)
         {
           table->covering_keys&= field->part_of_key;
@@ -4361,7 +4361,7 @@
       thus we safely can take table from the first field.
     */
     field= static_cast<Item_field *>(f++);
-    table= field->field->table;
+    table= field->field->getTable();
     table->auto_increment_field_not_null= false;
     f.rewind();
   }
@@ -4371,7 +4371,7 @@
     value= v++;
 
     Field *rfield= field->field;
-    table= rfield->table;
+    table= rfield->getTable();
 
     if (rfield == table->next_number_field)
       table->auto_increment_field_not_null= true;
@@ -4428,13 +4428,13 @@
       On INSERT or UPDATE fields are checked to be from the same table,
       thus we safely can take table from the first field.
     */
-    table= (*ptr)->table;
+    table= (*ptr)->getTable();
     table->auto_increment_field_not_null= false;
   }
   while ((field = *ptr++) && ! session->is_error())
   {
     value=v++;
-    table= field->table;
+    table= field->getTable();
     if (field == table->next_number_field)
       table->auto_increment_field_not_null= true;
     if (value->save_in_field(field, 0) < 0)

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2010-07-09 21:43:25 +0000
+++ drizzled/sql_select.cc	2010-07-16 05:40:08 +0000
@@ -598,7 +598,7 @@
       if (field->getValue()->type() == Item::NULL_ITEM &&
 	  ! field->getField()->real_maybe_null())
       {
-	field->getField()->table->reginfo.not_exists_optimize= 1;
+	field->getField()->getTable()->reginfo.not_exists_optimize= 1;
       }
     }
   }
@@ -933,7 +933,7 @@
 bool store_val_in_field(Field *field, Item *item, enum_check_fields check_flag)
 {
   bool error;
-  Table *table= field->table;
+  Table *table= field->getTable();
   Session *session= table->in_use;
   ha_rows cuted_fields=session->cuted_fields;
 
@@ -1159,7 +1159,7 @@
           Item *notnull;
           assert(item->type() == Item::FIELD_ITEM);
           Item_field *not_null_item= (Item_field*)item;
-          JoinTable *referred_tab= not_null_item->field->table->reginfo.join_tab;
+          JoinTable *referred_tab= not_null_item->field->getTable()->reginfo.join_tab;
           /*
             For UPDATE queries such as:
             UPDATE t1 SET t1.f2=(SELECT MAX(t2.f4) FROM t2 WHERE t2.f3=t1.f1);
@@ -1288,7 +1288,7 @@
   case Item::FIELD_ITEM:
     {
       Item_field *item_field= (Item_field*)item;
-      if (item_field->field->table != tbl)
+      if (item_field->field->getTable() != tbl)
         return true;
       return item_field->field->part_of_key.test(keyno);
     }
@@ -2324,7 +2324,7 @@
   if (outer_ref)
     return cmp;
   JoinTable **idx= (JoinTable **) table_join_idx;
-  cmp= idx[field2->field->table->tablenr]-idx[field1->field->table->tablenr];
+  cmp= idx[field2->field->getTable()->tablenr]-idx[field1->field->getTable()->tablenr];
   return cmp < 0 ? -1 : (cmp ? 1 : 0);
 }
 
@@ -2571,9 +2571,9 @@
       while ((item_field= it++))
       {
         Field *field= item_field->field;
-        JoinTable *stat= field->table->reginfo.join_tab;
+        JoinTable *stat= field->getTable()->reginfo.join_tab;
         key_map possible_keys= field->key_start;
-        possible_keys&= field->table->keys_in_use_for_query;
+        possible_keys&= field->getTable()->keys_in_use_for_query;
         stat[0].const_keys|= possible_keys;
 
         /*
@@ -2583,7 +2583,7 @@
         */
         if (possible_keys.any())
         {
-          Table *field_tab= field->table;
+          Table *field_tab= field->getTable();
           optimizer::KeyUse *use;
           for (use= stat->keyuse; use && use->getTable() == field_tab; use++)
             if (possible_keys.test(use->getKey()) &&
@@ -3027,7 +3027,7 @@
     {
       Field *field= ((Item_field*) args[0])->field;
       if (field->flags & AUTO_INCREMENT_FLAG 
-          && ! field->table->maybe_null 
+          && ! field->getTable()->maybe_null 
           && session->options & OPTION_AUTO_IS_NULL
           && (
             session->first_successful_insert_id_in_prev_stmt > 0 
@@ -4276,9 +4276,9 @@
 {
   Field *field=left_item->field;
   // No need to change const test. We also have to keep tests on LEFT JOIN
-  if (!field->table->const_table && !field->table->maybe_null)
+  if (not field->getTable()->const_table && !field->getTable()->maybe_null)
   {
-    Item *ref_item=part_of_refkey(field->table,field);
+    Item *ref_item=part_of_refkey(field->getTable(),field);
     if (ref_item && ref_item->eq(right_item,1))
     {
       right_item= right_item->real_item();
@@ -6145,7 +6145,7 @@
           saved value
         */
         field= item->field;
-        item->result_field=field->new_field(session->mem_root,field->table, 1);
+        item->result_field=field->new_field(session->mem_root,field->getTable(), 1);
               /*
                 We need to allocate one extra byte for null handling and
                 another extra byte to not get warnings from purify in
@@ -6278,7 +6278,7 @@
       }
       else if ((field= item->get_tmp_table_field()))
       {
-        if (item->type() == Item::SUM_FUNC_ITEM && field->table->group)
+        if (item->type() == Item::SUM_FUNC_ITEM && field->getTable()->group)
           item_field= ((Item_sum*) item)->result_item(field);
         else
           item_field= (Item*) new Item_field(field);

=== modified file 'drizzled/stored_key.h'
--- drizzled/stored_key.h	2010-05-20 06:34:25 +0000
+++ drizzled/stored_key.h	2010-07-16 05:40:08 +0000
@@ -62,12 +62,12 @@
                                     null,
                                     1,
                                     field_arg->field_name,
-                                    field_arg->table->getMutableShare(),
+                                    field_arg->getTable()->getMutableShare(),
                                     field_arg->charset());
-      to_field->init(field_arg->table);
+      to_field->init(field_arg->getTable());
     }
     else
-      to_field= field_arg->new_key_field(session->mem_root, field_arg->table,
+      to_field= field_arg->new_key_field(session->mem_root, field_arg->getTable(),
                                         ptr, null, 1);
 
     to_field->setWriteSet();
@@ -84,7 +84,7 @@
   enum store_key_result copy()
   {
     enum store_key_result result;
-    Session *session= to_field->table->in_use;
+    Session *session= to_field->getTable()->in_use;
     enum_check_fields saved_count_cuted_fields= session->count_cuted_fields;
     session->count_cuted_fields= CHECK_FIELD_IGNORE;
     result= copy_inner();

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2010-06-25 19:38:04 +0000
+++ drizzled/table.cc	2010-07-16 05:40:08 +0000
@@ -739,7 +739,7 @@
                                    org_field->charset());
   else
     new_field= org_field->new_field(session->mem_root, table,
-                                    table == org_field->table);
+                                    table == org_field->getTable());
   if (new_field)
   {
     new_field->init(table);
@@ -1190,7 +1190,7 @@
       ptrdiff_t diff;
       Field *orig_field= default_field[i];
       /* Get the value from default_values */
-      diff= (ptrdiff_t) (orig_field->table->getDefaultValues() - orig_field->table->record[0]);
+      diff= (ptrdiff_t) (orig_field->getTable()->getDefaultValues() - orig_field->getTable()->record[0]);
       orig_field->move_field_offset(diff);      // Points now at default_values
       if (orig_field->is_real_null())
         field->set_null();

=== modified file 'drizzled/table_share.cc'
--- drizzled/table_share.cc	2010-06-29 13:47:17 +0000
+++ drizzled/table_share.cc	2010-07-16 05:40:08 +0000
@@ -1520,7 +1520,7 @@
     }
 
     /* hack to undo f->init() */
-    f->table= NULL;
+    f->setTable(NULL);
     f->orig_table= NULL;
 
     f->field_index= fieldnr;

=== modified file 'plugin/heap/ha_heap.cc'
--- plugin/heap/ha_heap.cc	2010-06-29 21:22:35 +0000
+++ plugin/heap/ha_heap.cc	2010-07-16 05:40:08 +0000
@@ -738,7 +738,7 @@
     HP_COLUMNDEF* column= columndef + column_idx;
     column->type= (uint16_t)field->type();
     column->length= field->pack_length();
-    column->offset= field->offset(field->table->record[0]);
+    column->offset= field->offset(field->getTable()->record[0]);
 
     if (field->null_bit)
     {

=== modified file 'plugin/pbxt/src/systab_xt.cc'
--- plugin/pbxt/src/systab_xt.cc	2010-06-28 17:44:27 +0000
+++ plugin/pbxt/src/systab_xt.cc	2010-07-16 05:40:08 +0000
@@ -134,7 +134,7 @@
 static void xt_my_set_notnull_in_record(Field *field, char *record)
 {
 	if (field->null_ptr)
-		record[(uint) (field->null_ptr - (uchar *) field->table->record[0])] &= (uchar) ~field->null_bit;
+		record[(uint) (field->null_ptr - (uchar *) field->getTable()->record[0])] &= (uchar) ~field->null_bit;
 }
 
 /*
@@ -365,7 +365,7 @@
 #if MYSQL_VERSION_ID < 50114
 		curr_field->ptr = (byte *) buf + curr_field->offset();
 #else
-		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->table->record[0]);
+		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->getTable()->record[0]);
 #endif
 		switch (curr_field->field_name[0]) {
 			case 'P':
@@ -476,7 +476,7 @@
 #if MYSQL_VERSION_ID < 50114
 		curr_field->ptr = (byte *) buf + curr_field->offset();
 #else
-		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->table->record[0]);
+		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->getTable()->record[0]);
 #endif
 		switch (curr_field->field_name[0]) {
 			case 'I':

